"""
Blessed Amplitude connector for Airbyte SDK.

Auto-generated from OpenAPI specification.
"""

from .connector import AmplitudeConnector
from .models import (
    AmplitudeAuthConfig,
    AmplitudeReplicationConfig,
    Annotation,
    AnnotationV3Category,
    AnnotationV3,
    AnnotationsList,
    AnnotationGetResponse,
    Cohort,
    CohortGetResponse,
    CohortsList,
    EventType,
    EventsListResponse,
    ActiveUsersDataSeriesmetaItem,
    ActiveUsersData,
    ActiveUsersResponse,
    AverageSessionLengthDataSeriescollapsedItemItem,
    AverageSessionLengthDataSeriesmetaItem,
    AverageSessionLengthData,
    AverageSessionLengthResponse,
    AmplitudeCheckResult,
    AmplitudeExecuteResult,
    AmplitudeExecuteResultWithMeta,
    AnnotationsListResult,
    CohortsListResult,
    EventsListListResult,
    ActiveUsersListResult,
    AverageSessionLengthListResult,
    AirbyteSearchMeta,
    AirbyteSearchResult,
    AnnotationsSearchData,
    AnnotationsSearchResult,
    CohortsSearchData,
    CohortsSearchResult,
    EventsListSearchData,
    EventsListSearchResult,
    ActiveUsersSearchData,
    ActiveUsersSearchResult,
    AverageSessionLengthSearchData,
    AverageSessionLengthSearchResult
)
from .types import (
    AnnotationsListParams,
    AnnotationsGetParams,
    CohortsListParams,
    CohortsGetParams,
    EventsListListParams,
    ActiveUsersListParams,
    AverageSessionLengthListParams,
    AirbyteSearchParams,
    AirbyteSortOrder,
    AnnotationsSearchFilter,
    AnnotationsSearchQuery,
    AnnotationsCondition,
    CohortsSearchFilter,
    CohortsSearchQuery,
    CohortsCondition,
    EventsListSearchFilter,
    EventsListSearchQuery,
    EventsListCondition,
    ActiveUsersSearchFilter,
    ActiveUsersSearchQuery,
    ActiveUsersCondition,
    AverageSessionLengthSearchFilter,
    AverageSessionLengthSearchQuery,
    AverageSessionLengthCondition
)
from ._vendored.connector_sdk.types import AirbyteHostedAuthConfig as AirbyteAuthConfig

__all__ = [
    "AmplitudeConnector",
    "AirbyteAuthConfig",
    "AmplitudeAuthConfig",
    "AmplitudeReplicationConfig",
    "Annotation",
    "AnnotationV3Category",
    "AnnotationV3",
    "AnnotationsList",
    "AnnotationGetResponse",
    "Cohort",
    "CohortGetResponse",
    "CohortsList",
    "EventType",
    "EventsListResponse",
    "ActiveUsersDataSeriesmetaItem",
    "ActiveUsersData",
    "ActiveUsersResponse",
    "AverageSessionLengthDataSeriescollapsedItemItem",
    "AverageSessionLengthDataSeriesmetaItem",
    "AverageSessionLengthData",
    "AverageSessionLengthResponse",
    "AmplitudeCheckResult",
    "AmplitudeExecuteResult",
    "AmplitudeExecuteResultWithMeta",
    "AnnotationsListResult",
    "CohortsListResult",
    "EventsListListResult",
    "ActiveUsersListResult",
    "AverageSessionLengthListResult",
    "AirbyteSearchMeta",
    "AirbyteSearchResult",
    "AnnotationsSearchData",
    "AnnotationsSearchResult",
    "CohortsSearchData",
    "CohortsSearchResult",
    "EventsListSearchData",
    "EventsListSearchResult",
    "ActiveUsersSearchData",
    "ActiveUsersSearchResult",
    "AverageSessionLengthSearchData",
    "AverageSessionLengthSearchResult",
    "AnnotationsListParams",
    "AnnotationsGetParams",
    "CohortsListParams",
    "CohortsGetParams",
    "EventsListListParams",
    "ActiveUsersListParams",
    "AverageSessionLengthListParams",
    "AirbyteSearchParams",
    "AirbyteSortOrder",
    "AnnotationsSearchFilter",
    "AnnotationsSearchQuery",
    "AnnotationsCondition",
    "CohortsSearchFilter",
    "CohortsSearchQuery",
    "CohortsCondition",
    "EventsListSearchFilter",
    "EventsListSearchQuery",
    "EventsListCondition",
    "ActiveUsersSearchFilter",
    "ActiveUsersSearchQuery",
    "ActiveUsersCondition",
    "AverageSessionLengthSearchFilter",
    "AverageSessionLengthSearchQuery",
    "AverageSessionLengthCondition",
]